@@ -7,6 +7,8 @@
 import subprocess
 import sys
 import os
+import time
+from progress.bar import IncrementalBar
 
 
 def install(package: str, check=True):
@@ -23,7 +25,12 @@ def pip_upgrade():
 
 
 def required():
+    require = ["requests", "opencv-python", "progress"]
+    bar = IncrementalBar('Countdown', max=len(require))
     print("Установка необходимых библиотек")
-    install("requests", check=False)
-    install("opencv-python", check=False)
+    for i in range(len(require)):
+        install(require[i], check=False)
+        bar.next()
+        time.sleep(1)
+    bar.finish()
     print("Установка завершена")
